##  Prerequisites
You need an admin role for your SAP LeanIX workspace.
This tutorial assumes you have a basic understanding of:
  * [LeanIX Data Interchange Format (LDIF)](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a99087a441014a04fa6cda4e0ec2b__leanix_data_interchange_format_ldif) of the Integration API
  * [Inbound processors](https://help.sap.com/docs/leanix/ea/inbound-processors?locale=en-US&state=PRODUCTION&version=CLOUD) of the Integration API, including the inboundFactSheet processor
  * [Fact sheets](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.") in SAP LeanIX
